@@ -25,11 +25,14 @@ An emoji picker for ibus typing booster.
 from typing import Any
 from typing import List
 from typing import Tuple
+from typing import Iterable
 from typing import Dict
 from typing import Optional
+from typing import Callable
 import sys
 import os
 import re
+import ast
 import signal
 import argparse
 import locale
@@ -39,8 +42,6 @@ import unicodedata
 import html
 import logging
 import logging.handlers
-import itb_util
-import itb_pango
 
 from gi import require_version # type: ignore
 require_version('GLib', '2.0')
@@ -58,6 +59,8 @@ require_version('Gtk', '3.0')
 from gi.repository import Gtk
 from gi.repository import GObject
 import itb_emoji
+import itb_util
+import itb_pango
 import itb_version
 
 LOGGER = logging.getLogger('ibus-typing-booster')
@@ -67,8 +70,8 @@ GTK_VERSION = (Gtk.get_major_version(),
                Gtk.get_micro_version())
 
 DOMAINNAME = 'ibus-typing-booster'
-_ = lambda a: gettext.dgettext(DOMAINNAME, a)
-N_ = lambda a: a
+_: Callable[[str], str] = lambda a: gettext.dgettext(DOMAINNAME, a)
+N_: Callable[[str], str] = lambda a: a
 
 def parse_args() -> Any:
     '''
@@ -83,11 +86,11 @@ def parse_args() -> Any:
         action='store',
         default='',
         help=('Set a list of languages to be used when browsing '
-              + 'or searching for emoji. For example: '
-              + '"emoji-picker -l de:fr:ja" '
-              + 'would use German, French, and Japanese. '
-              + 'If empty, the locale settings are used to '
-              + 'determine the languages.'))
+              'or searching for emoji. For example: '
+              '"emoji-picker -l de:fr:ja" '
+              'would use German, French, and Japanese. '
+              'If empty, the locale settings are used to '
+              'determine the languages.'))
     parser.add_argument(
         '-f', '--font',
         nargs='?',
@@ -95,9 +98,9 @@ def parse_args() -> Any:
         action='store',
         default=None,
         help=('Set a font to display emoji. '
-              + 'If not specified, the font is read from the config file. '
-              + 'To use the system default font specify "emoji". '
-              + 'default: "%(default)s"'))
+              'If not specified, the font is read from the config file. '
+              'To use the system default font specify "emoji". '
+              'default: "%(default)s"'))
     parser.add_argument(
         '-s', '--fontsize',
         nargs='?',
@@ -105,24 +108,24 @@ def parse_args() -> Any:
         action='store',
         default=None,
         help=('Set a fontsize to display emoji. '
-              + 'If not specified, the fontsize is read from the config file. '
-              + 'If that fails 24 is used as a fall back fontsize. '
-              + 'default: "%(default)s"'))
+              'If not specified, the fontsize is read from the config file. '
+              'If that fails 24 is used as a fall back fontsize. '
+              'default: "%(default)s"'))
     parser.add_argument(
         '-m', '--modal',
         action='store_true',
         default=False,
         help=('Make the window of emoji-picker modal. '
-              + 'default: %(default)s'))
+              'default: %(default)s'))
     parser.add_argument(
         '-a', '--all',
         action='store_true',
         default=False,
         help=('Load all Unicode characters. '
-              + 'Makes all Unicode characters accessible, '
-              + 'even normal letters. '
-              + 'Slows the search down and is usually not needed. '
-              + 'default: %(default)s'))
+              'Makes all Unicode characters accessible, '
+              'even normal letters. '
+              'Slows the search down and is usually not needed. '
+              'default: %(default)s'))
     parser.add_argument(
         '--fallback',
         nargs='?',
@@ -130,12 +133,12 @@ def parse_args() -> Any:
         action='store',
         default=None,
         help=('Whether to use fallback fonts when rendering emoji. '
-              + 'If not 0, pango will use fallback fonts as necessary. '
-              + 'If 0, pango will use only glyphs from '
-              + 'the closest matching font on the system. No fallback '
-              + 'will be done to other fonts on the system that '
-              + 'might contain the glyhps needed to render an emoji. '
-              + 'default: "%(default)s"')
+              'If not 0, pango will use fallback fonts as necessary. '
+              'If 0, pango will use only glyphs from '
+              'the closest matching font on the system. No fallback '
+              'will be done to other fonts on the system that '
+              'might contain the glyhps needed to render an emoji. '
+              'default: "%(default)s"')
         )
     parser.add_argument(
         '--emoji_unicode_min',
@@ -144,8 +147,8 @@ def parse_args() -> Any:
         action='store',
         default='0.0',
         help=('Load only emoji which were added to Unicode '
-              + 'not earlier than this Unicode version. '
-              + 'default: %(default)s'))
+              'not earlier than this Unicode version. '
+              'default: %(default)s'))
     # Guess current Unicode version:
     unicode_versions = (
         ('20180605', '11.0'),
@@ -167,37 +170,37 @@ def parse_args() -> Any:
         action='store',
         default=current_unicode_version,
         help=('Load only emoji which were added to Unicode '
-              + 'not later than this Unicode version. '
-              + 'default: %(default)s'))
+              'not later than this Unicode version. '
+              'default: %(default)s'))
     parser.add_argument(
         '-d', '--debug',
         action='store_true',
         default=False,
         help=('Print some debug output to stdout. '
-              + 'default: %(default)s'))
+              'default: %(default)s'))
     parser.add_argument(
         '--version',
         action='store_true',
         default=False,
         help=('Output version information and exit. '
-              + 'default: %(default)s'))
+              'default: %(default)s'))
     return parser.parse_args()
 
 _ARGS = parse_args()
 
-class EmojiPickerUI(Gtk.Window):
+class EmojiPickerUI(Gtk.Window): # type: ignore
     '''
     User interface of the emoji picker
     '''
     def __init__(self,
-                 languages=('en_US',),
-                 modal=False,
-                 unicode_data_all=False,
-                 emoji_unicode_min=1.0,
-                 emoji_unicode_max=100.0,
-                 font=None,
-                 fontsize=None,
-                 fallback=None) -> None:
+                 languages: Iterable[str] = ('en_US',),
+                 modal: bool = False,
+                 unicode_data_all: bool = False,
+                 emoji_unicode_min: str = '1.0',
+                 emoji_unicode_max: str = '100.0',
+                 font: Optional[str] = None,
+                 fontsize: Optional[float] = None,
+                 fallback: Optional[bool] = None) -> None:
         Gtk.Window.__init__(self, title='🚀 ' + _('Emoji Picker'))
 
         self.set_name('EmojiPicker')
@@ -224,19 +227,6 @@ class EmojiPickerUI(Gtk.Window):
             Gdk.Screen.get_default(),
             style_provider,
             Gtk.STYLE_PROVIDER_PRIORITY_APPLICATION)
-
-        # https://tronche.com/gui/x/icccm/sec-4.html#WM_CLASS
-        # gnome-shell seems to use the first argument of set_wmclass()
-        # to find the .desktop file.  If the .desktop file can be
-        # found, the name shown by gnome-shell in the top bar comes
-        # from that .desktop file and the icon to show is also read
-        # from that .desktop file. If the .desktop file cannot be
-        # found, the second argument of set_wmclass() is shown by
-        # gnome-shell in the top bar.
-        #
-        # It only works like this when gnome-shell runs under Xorg
-        # though, under Wayland things are different.
-        self.set_wmclass('emoji-picker', 'Emoji Picker')
         self.set_default_size(700, 400)
         self._modal = modal
         self.set_modal(self._modal)
@@ -301,8 +291,10 @@ class EmojiPickerUI(Gtk.Window):
         self._skin_tone_popover: Optional[Gtk.Popover] = None
         self._skin_tone_selected_popover: Optional[Gtk.Popover] = None
 
-        self._main_container = Gtk.VBox()
-        self.add(self._main_container)
+        self._main_container = Gtk.Box()
+        self._main_container.set_orientation(Gtk.Orientation.VERTICAL)
+        self._main_container.set_spacing(0)
+        self.add(self._main_container) # pylint: disable=no-member
         self._header_bar = Gtk.HeaderBar()
         self._header_bar.set_hexpand(True)
         self._header_bar.set_vexpand(False)
@@ -313,23 +305,23 @@ class EmojiPickerUI(Gtk.Window):
         self._main_menu_popover = Gtk.Popover()
         self._main_menu_popover.set_relative_to(self._main_menu_button)
         self._main_menu_popover.set_position(Gtk.PositionType.BOTTOM)
-        self._main_menu_popover_vbox = Gtk.VBox()
+        self._main_menu_popover_vbox = Gtk.Box()
+        self._main_menu_popover_vbox.set_orientation(Gtk.Orientation.VERTICAL)
+        self._main_menu_popover_vbox.set_spacing(0)
         self._main_menu_clear_recently_used_button = Gtk.Button(
             label=_('Clear recently used'))
         self._main_menu_clear_recently_used_button.connect(
             'clicked', self.on_clear_recently_used_button_clicked)
-        self._main_menu_popover_vbox.pack_start(
-            self._main_menu_clear_recently_used_button, False, False, 0)
+        self._main_menu_popover_vbox.add(
+            self._main_menu_clear_recently_used_button)
         if not self._modal:
             self._main_menu_about_button = Gtk.Button(label=_('About'))
             self._main_menu_about_button.connect(
                 'clicked', self.on_about_button_clicked)
-            self._main_menu_popover_vbox.pack_start(
-                self._main_menu_about_button, False, False, 0)
+            self._main_menu_popover_vbox.add(self._main_menu_about_button)
         self._main_menu_quit_button = Gtk.Button(label=_('Quit'))
         self._main_menu_quit_button.connect('clicked', self.on_delete_event)
-        self._main_menu_popover_vbox.pack_start(
-            self._main_menu_quit_button, False, False, 0)
+        self._main_menu_popover_vbox.add(self._main_menu_quit_button)
         self._main_menu_popover.add(self._main_menu_popover_vbox)
         self._main_menu_button.connect(
             'clicked', self.on_main_menu_button_clicked)
@@ -408,7 +400,7 @@ class EmojiPickerUI(Gtk.Window):
             'grab-focus', self.on_search_entry_grab_focus)
 
         self._browse_paned = Gtk.HPaned()
-        self._main_container.pack_start(self._browse_paned, True, True, 0)
+        self._main_container.add(self._browse_paned)
         self._browse_paned.set_wide_handle(True)
         self._browse_paned.set_hexpand(True)
         self._browse_paned.set_vexpand(True)
@@ -431,15 +423,21 @@ class EmojiPickerUI(Gtk.Window):
         self._flowbox_scroll.set_overlay_scrolling(True)
         self._flowbox = Gtk.FlowBox()
         self._flowbox_scroll.add(self._flowbox)
-        self._long_press_gestures: List[Tuple[Any, Tuple[Any, Any, Any, Any]]] = []
+        self._long_press_gestures: List[
+            Tuple[Any, Tuple[Any, Any, Any, Any]]] = []
 
-        self._left_pane = Gtk.VBox()
+        self._left_pane = Gtk.Box()
+        self._left_pane.set_orientation(Gtk.Orientation.VERTICAL)
+        self._left_pane.set_spacing(0)
         self._left_pane.set_homogeneous(False)
-        self._left_pane.pack_start(self._search_bar, False, False, 0)
-        self._left_pane.pack_start(self._browse_treeview_scroll, True, True, 0)
+        self._left_pane.add(self._search_bar)
+        self._left_pane.add(self._browse_treeview_scroll)
 
-        self._right_pane = Gtk.VBox()
-        self._right_pane.pack_start(self._flowbox_scroll, True, True, 0)
+        self._right_pane = Gtk.Box()
+        self._right_pane.set_orientation(Gtk.Orientation.VERTICAL)
+        self._right_pane.set_spacing(0)
+        self._right_pane.set_homogeneous(False)
+        self._right_pane.add(self._flowbox_scroll)
 
         self._browse_paned.pack1(
             self._left_pane, resize=True, shrink=True)
@@ -502,11 +500,11 @@ class EmojiPickerUI(Gtk.Window):
         if _ARGS.debug:
             LOGGER.debug(
                 'expanded_languages  = %s\n'
-                %itb_util.expand_languages(self._languages)
-                + 'first_language_with_categories = %s\n'
-                %first_language_with_categories
-                + 'number_of_empty_languages = %s\n'
-                %number_of_empty_languages)
+                'first_language_with_categories = %s\n'
+                'number_of_empty_languages = %s\n',
+                itb_util.expand_languages(self._languages),
+                first_language_with_categories,
+                number_of_empty_languages)
 
         self._browse_treeview.append_column(
             Gtk.TreeViewColumn(
@@ -526,7 +524,7 @@ class EmojiPickerUI(Gtk.Window):
 
         self._browse_treeview.columns_autosize()
 
-        self.show_all()
+        self.show_all() # pylint: disable=no-member
 
         (dummy_minimum_width_search_entry,
          natural_width_search_entry) = self._search_entry.get_preferred_width()
@@ -535,9 +533,9 @@ class EmojiPickerUI(Gtk.Window):
         if _ARGS.debug:
             LOGGER.debug(
                 'natural_width_search_entry = %s '
-                %natural_width_search_entry
-                + 'natural_width_search_bar = %s\n'
-                %natural_width_search_bar)
+                'natural_width_search_bar = %s\n',
+                natural_width_search_entry,
+                natural_width_search_bar)
         self._browse_paned.set_position(natural_width_search_bar)
 
         self._selection_clipboard = Gtk.Clipboard.get(
@@ -633,7 +631,7 @@ class EmojiPickerUI(Gtk.Window):
             N_('Keywords'),
         ]
         if self._gettext_translations[language]:
-            return self._gettext_translations[language].gettext(key)
+            return str(self._gettext_translations[language].gettext(key))
         return key
 
     def _emoji_descriptions(self, emoji: str) -> List[str]:
@@ -647,10 +645,10 @@ class EmojiPickerUI(Gtk.Window):
         '''
         descriptions = []
         descriptions.append(
-            ' '.join(['U+%X' %ord(character) for character in emoji]))
+            ' '.join([f'U+{ord(character):04X}' for character in emoji]))
         for language in itb_util.expand_languages(self._languages):
             names = self._emoji_matcher.names(emoji, language=language)
-            description = '<b>%s</b>' %language
+            description = f'<b>{language}</b>'
             description_empty = True
             if names:
                 description += '\n' + html.escape(', '.join(names))
@@ -677,12 +675,12 @@ class EmojiPickerUI(Gtk.Window):
             fonts_description += '\n'
             code_points = ''
             for char in text:
-                code_points += ' U+%X' %ord(char)
+                code_points += f' U+{ord(char):04X}'
             fonts_description += (
-                '<span font="%s" fallback="%s" >'
-                %(self._font, str(self._fallback).lower())
+                f'<span font="{self._font}" '
+                f'fallback="{str(self._fallback).lower()}" >'
                 + text + '</span>'
-                + '<span fallback="true">%s</span>' % code_points)
+                + f'<span fallback="true">{code_points}</span>')
             fonts_description += ': ' + font_family
         descriptions.append(fonts_description)
         if self._emoji_matcher.unicode_version(emoji):
@@ -691,9 +689,9 @@ class EmojiPickerUI(Gtk.Window):
                 + self._emoji_matcher.unicode_version(emoji))
         if _ARGS.debug:
             descriptions.append(
-                'emoji_order = %s' %self._emoji_matcher.emoji_order(emoji))
+                f'emoji_order = {self._emoji_matcher.emoji_order(emoji)}')
             descriptions.append(
-                'cldr_order = %s' %self._emoji_matcher.cldr_order(emoji))
+                f'cldr_order = {self._emoji_matcher.cldr_order(emoji)}')
             descriptions.append(
                 'Emoji properties from unicode.org:' + '\n'
                 + ', '.join(self._emoji_matcher.properties(emoji)))
@@ -800,15 +798,14 @@ class EmojiPickerUI(Gtk.Window):
             gtk_label = Gtk.Label()
             # Make font for emoji large using pango markup
             text = (
-                '<span font="%s %s" fallback="%s">'
-                %(self._font, self._fontsize, str(self._fallback).lower())
+                f'<span font="{self._font} {self._fontsize}" '
+                f'fallback="{str(self._fallback).lower()}">'
                 + html.escape(emoji)
                 + '</span>')
             if itb_emoji.is_invisible(emoji):
                 text += (
-                    '<span fallback="false" font="%s">'
-                    %(self._fontsize / 2)
-                    + ' U+%X ' %ord(emoji)
+                    f'<span fallback="false" font="{self._fontsize / 2}">'
+                    f' U+{ord(emoji):04X} '
                     + self._emoji_matcher.name(emoji)
                     + '</span>')
             gtk_label.set_text(text)
@@ -868,7 +865,7 @@ class EmojiPickerUI(Gtk.Window):
         for child in self._flowbox.get_children():
             child.set_can_focus(False)
 
-        self.show_all()
+        self.show_all() # pylint: disable=no-member
         self._busy_stop()
 
     def _read_options(self) -> None:
@@ -878,14 +875,17 @@ class EmojiPickerUI(Gtk.Window):
         options_dict = {}
         if os.path.isfile(self._options_file):
             try:
-                options_dict = eval(open(
-                    self._options_file,
-                    mode='r',
-                    encoding='UTF-8').read())
-            except (PermissionError, SyntaxError, IndentationError):
-                LOGGER.exception('Error when reading options')
-            except Exception as dummy_exception:
-                LOGGER.exception('Unknown error when reading options')
+                with open(self._options_file,
+                          mode='r',
+                          encoding='UTF-8') as options_file:
+                    options_dict = ast.literal_eval(options_file.read())
+            except (PermissionError, SyntaxError, IndentationError) as error:
+                LOGGER.exception('Error when reading options: %s: %s',
+                                 error.__class__.__name__, error)
+            except Exception as error:
+                LOGGER.exception(
+                    'Unexpected error when reading options: %s: %s',
+                    error.__class__.__name__, error)
             else: # no exception occured
                 if _ARGS.debug:
                     LOGGER.debug(
@@ -941,16 +941,18 @@ class EmojiPickerUI(Gtk.Window):
         recently_used_emoji = {}
         if os.path.isfile(self._recently_used_emoji_file):
             try:
-                recently_used_emoji = eval(open(
-                    self._recently_used_emoji_file,
-                    mode='r',
-                    encoding='UTF-8').read())
-            except (PermissionError, SyntaxError, IndentationError):
-                import traceback
-                traceback.print_exc()
-            except Exception as dummy_exception:
-                import traceback
-                traceback.print_exc()
+                with open(self._recently_used_emoji_file,
+                          mode='r',
+                          encoding='UTF-8') as recently_used_file:
+                    recently_used_emoji = ast.literal_eval(
+                        recently_used_file.read())
+            except (PermissionError, SyntaxError, IndentationError) as error:
+                LOGGER.exception('Error reading recently used emoji: %s: %s',
+                                 error.__class__.__name__, error)
+            except Exception as error:
+                LOGGER.exception(
+                    'Unexpected error reading recently used emoji: %s: %s',
+                    error.__class__.__name__, error)
             else: # no exception occured
                 if _ARGS.debug:
                     LOGGER.debug(
@@ -973,7 +975,7 @@ class EmojiPickerUI(Gtk.Window):
             self._init_recently_used()
         self._cleanup_recently_used()
 
-    def _cleanup_recently_used(self):
+    def _cleanup_recently_used(self) -> None:
         '''
         Reduces the size of the recently used dictionary
         if it has become too big.
@@ -1001,7 +1003,8 @@ class EmojiPickerUI(Gtk.Window):
                 ('', '', self._recently_used_label)):
             self._clear_flowbox()
 
-    def on_clear_recently_used_button_clicked(self, _button: Gtk.Button) -> None:
+    def on_clear_recently_used_button_clicked(
+            self, _button: Gtk.Button) -> None:
         '''
         :param _button: The “Clear recently used” button
         '''
@@ -1052,7 +1055,8 @@ class EmojiPickerUI(Gtk.Window):
         self._selection_clipboard.store()
         self._selection_primary.store() # Does not work.
 
-    def _show_concise_emoji_description_in_header_bar(self, emoji: str) -> None:
+    def _show_concise_emoji_description_in_header_bar(
+            self, emoji: str) -> None:
         '''
         Show a concise description of an emoji in the header bar
         of the program.
@@ -1079,7 +1083,8 @@ class EmojiPickerUI(Gtk.Window):
                     + ', '.join(keywords))
                 break
 
-    def _print_profiling_information(self) -> None:
+    @staticmethod
+    def _print_profiling_information() -> None:
         '''
         Print some profiling information to the log.
         '''
@@ -1092,7 +1097,7 @@ class EmojiPickerUI(Gtk.Window):
         stats.print_stats('itb_emoji', 25)
         LOGGER.info('Profiling info:\n%s', stats_stream.getvalue())
 
-    def on_delete_event(self, *_args) -> None:
+    def on_delete_event(self, *_args: Any) -> None:
         '''
         The window has been deleted, probably by the window manager.
         '''
@@ -1101,7 +1106,7 @@ class EmojiPickerUI(Gtk.Window):
             self._print_profiling_information()
         Gtk.main_quit()
 
-    def on_destroy_event(self, *_args) -> None:
+    def on_destroy_event(self, *_args: Any) -> None:
         '''
         The window has been destroyed.
         '''
@@ -1222,12 +1227,11 @@ class EmojiPickerUI(Gtk.Window):
             label = Gtk.Label()
             # Make font for emoji large using pango markup
             label.set_text(
-                '<span font="%s %s" fallback="%s">'
-                %(self._font, self._fontsize, str(self._fallback).lower())
+                f'<span font="{self._font} {self._fontsize}" '
+                f'fallback="{str(self._fallback).lower()}">'
                 + html.escape(emoji)
                 + '</span>'
-                + '<span font="%s">'
-                %(self._fontsize / 2)
+                + f'<span font="{self._fontsize / 2}">'
                 + ' ' + html.escape(name)
                 + '</span>')
             label.set_use_markup(True)
@@ -1285,7 +1289,7 @@ class EmojiPickerUI(Gtk.Window):
         for child in self._flowbox.get_children():
             child.set_can_focus(False)
 
-        self.show_all()
+        self.show_all() # pylint: disable=no-member
         self._candidates_invalid = False
         self._busy_stop()
 
@@ -1368,10 +1372,10 @@ class EmojiPickerUI(Gtk.Window):
             return
         if _ARGS.debug:
             LOGGER.debug(
-                'on_label_selected(): model[iterator] = %s\n'
-                %model[iterator][:]
-                + 'self._currently_selected_label = %s\n'
-                %repr(self._currently_selected_label))
+                'model[iterator] = %s\n'
+                'self._currently_selected_label = %s\n',
+                model[iterator][:],
+                repr(self._currently_selected_label))
         self._search_bar.set_search_mode(False)
         self._browse_treeview.grab_focus()
         language = model[iterator][1]
@@ -1436,7 +1440,7 @@ class EmojiPickerUI(Gtk.Window):
             self._emoji_selected_popover = None
         return False
 
-    def _emoji_event_box_selected(self, event_box): # FIXME add type hint
+    def _emoji_event_box_selected(self, event_box: Gtk.EventBox) -> bool:
         '''
         Called when an event box containing an emoji
         was selected in the flowbox.
@@ -1446,7 +1450,6 @@ class EmojiPickerUI(Gtk.Window):
         has been copied to the clipboard.
 
         :param event_box: The event box which contains the emoji
-        :type event_box: Gtk.EventBox object
         '''
         # Use .get_label() instead of .get_text() to fetch the text
         # from the label widget including any embedded underlines
@@ -1458,7 +1461,8 @@ class EmojiPickerUI(Gtk.Window):
             LOGGER.debug('text = %s\n', text)
         (emoji, name) = self._parse_emoji_and_name_from_text(text)
         if not emoji:
-            return Gdk.EVENT_PROPAGATE
+            # Gdk.EVENT_PROPAGATE is defined as False
+            return bool(Gdk.EVENT_PROPAGATE)
         self._show_concise_emoji_description_in_header_bar(emoji)
         self._set_clipboards(emoji)
         self._add_to_recently_used(emoji)
@@ -1479,6 +1483,7 @@ class EmojiPickerUI(Gtk.Window):
             self._emoji_selected_popover.popup()
         self._emoji_selected_popover.show_all()
         GLib.timeout_add(500, self._emoji_selected_popover_popdown)
+        return True # Gdk.EVENT_PROPAGATE is defined as False
 
     def on_emoji_selected(
             self,
@@ -1536,19 +1541,18 @@ class EmojiPickerUI(Gtk.Window):
             if emoji:
                 emoji = self._variation_selector_normalize_for_font(emoji)
                 new_text = (
-                    '<span font="%s %s" fallback="%s">'
-                    %(self._font, self._fontsize, str(self._fallback).lower())
+                    f'<span font="{self._font} {self._fontsize}" '
+                    f'fallback="{str(self._fallback).lower()}">'
                     + html.escape(emoji)
                     + '</span>')
                 if name:
                     new_text += (
-                        '<span fallback="true" font="%s">'
-                        %(self._fontsize / 2)
+                        f'<span fallback="true" font="{self._fontsize / 2}">'
                         + html.escape(name)
                         + '</span>')
                 label.set_text(new_text)
                 label.set_use_markup(True)
-        self.show_all()
+        self.show_all() # pylint: disable=no-member
         self._busy_stop()
 
     def _skin_tone_selected_popover_popdown(self) -> bool:
@@ -1620,16 +1624,16 @@ class EmojiPickerUI(Gtk.Window):
             # in a search results flowbox and we do *not* want
             # to replace the emoji.
             new_text = (
-                '<span font="%s %s" fallback="%s">'
-                %(self._font, self._fontsize, str(self._fallback).lower())
+                f'<span font="{self._font} {self._fontsize}" '
+                f'fallback="{str(self._fallback).lower()}">'
                 + html.escape(emoji)
                 + '</span>')
             label.set_text(new_text)
             label.set_use_markup(True)
         GLib.timeout_add(500, self._skin_tone_selected_popover_popdown)
 
+    @staticmethod
     def on_flowbox_event_box_long_press_begin(
-            self,
             gesture: Gtk.GestureLongPress,
             event_sequence: Gdk.EventSequence) -> None:
         '''
@@ -1639,12 +1643,10 @@ class EmojiPickerUI(Gtk.Window):
         :param event_sequence: the event sequence that the event belongs to
         '''
         if _ARGS.debug:
-            LOGGER.debug(
-                'on_flowbox_event_box_long_press_begin() %s %s\n',
-                repr(gesture), repr(event_sequence))
+            LOGGER.debug('%s %s\n', repr(gesture), repr(event_sequence))
 
+    @staticmethod
     def on_flowbox_event_box_long_press_cancel(
-            self,
             gesture: Gtk.GestureLongPress,
             event_sequence: Gdk.EventSequence) -> None:
         '''
@@ -1655,11 +1657,11 @@ class EmojiPickerUI(Gtk.Window):
         '''
         if _ARGS.debug:
             LOGGER.debug(
-                'on_flowbox_event_box_long_press_cancel() %s %s\n',
-                repr(gesture), repr(event_sequence))
+                '%s %s\n', repr(gesture), repr(event_sequence))
 
+    @staticmethod
     def on_flowbox_event_box_long_press_cancelled(
-            self, gesture: Gtk.GestureLongPress) -> None:
+            gesture: Gtk.GestureLongPress) -> None:
         '''
         Signal handler called whenever a press moved too far, or was
         released before “pressed” happened.
@@ -1667,27 +1669,26 @@ class EmojiPickerUI(Gtk.Window):
         :param gesture: The object which received the signal
         '''
         if _ARGS.debug:
-            LOGGER.debug(
-                'on_flowbox_event_box_long_press_cancelled() %s\n',
-                repr(gesture))
+            LOGGER.debug('%s\n', repr(gesture))
 
     def on_flowbox_event_box_long_press_pressed(
             self,
             gesture: Gtk.GestureLongPress,
-            x: int,
-            y: int,
+            x_coordinate: int,
+            y_coordinate: int,
             event_box: Gtk.EventBox) -> None:
         '''
         :param gesture: The object which received the signal
-        :param x: the X coordinate where the press happened,
-                  relative to the widget allocation
-        :param y: the Y coordinate where the press happened,
-                  relative to the widget allocation
+        :param x_coordinate: the X coordinate where the press happened,
+                             relative to the widget allocation
+        :param y_coordinate: the Y coordinate where the press happened,
+                             relative to the widget allocation
         '''
         if _ARGS.debug:
             LOGGER.debug(
                 'on_flowbox_event_box_long_press_pressed() %s %s %s %s\n',
-                repr(gesture), x, y, repr(event_box))
+                repr(gesture),
+                x_coordinate, y_coordinate, repr(event_box))
         self._show_skin_tone_popover(event_box)
 
     def on_flowbox_event_box_button_release(
@@ -1702,10 +1703,10 @@ class EmojiPickerUI(Gtk.Window):
         '''
         if _ARGS.debug:
             LOGGER.debug(
-                'on_flowbox_event_box_button_release() '
-                + 'event_button.type=%s ' %event_button.type
-                + 'event_button.window=%s ' %event_button.window
-                + 'event_button.button=%s\n' %event_button.button)
+                'event_button.type=%s '
+                'event_button.window=%s '
+                'event_button.button=%s\n',
+                event_button.type, event_button.window, event_button.button)
         if event_button.button == 1:
             # Call self._emoji_event_box_selected() in the release
             # event because here we know that it has not been a long
@@ -1795,8 +1796,8 @@ class EmojiPickerUI(Gtk.Window):
         for skin_tone_variant in skin_tone_variants:
             label = Gtk.Label()
             label.set_text(
-                '<span font="%s %s" fallback="%s">'
-                %(self._font, self._fontsize, str(self._fallback).lower())
+                f'<span font="{self._font} {self._fontsize}" '
+                f'fallback="{str(self._fallback).lower()}">'
                 + html.escape(skin_tone_variant)
                 + '</span>')
             label.set_use_markup(True)
@@ -1877,7 +1878,8 @@ class EmojiPickerUI(Gtk.Window):
             rectangle.width = self._fontsize * 1.5
             rectangle.height = self._fontsize * 1.5
             self._emoji_info_popover.set_pointing_to(rectangle)
-        emoji_info_popover_vbox = Gtk.VBox()
+        emoji_info_popover_vbox = Gtk.Box()
+        emoji_info_popover_vbox.set_orientation(Gtk.Orientation.VERTICAL)
         emoji_info_popover_vbox.set_vexpand(False)
         emoji_info_popover_vbox.set_hexpand(False)
         margin = 0
@@ -1887,12 +1889,11 @@ class EmojiPickerUI(Gtk.Window):
         emoji_info_popover_vbox.set_margin_bottom(margin)
         emoji_info_popover_vbox.set_spacing(margin)
         emoji_info_popover_scroll = Gtk.ScrolledWindow()
-        emoji_info_popover_vbox.pack_start(
-            emoji_info_popover_scroll, True, True, 0)
+        emoji_info_popover_vbox.add(emoji_info_popover_scroll)
         emoji_info_popover_listbox = Gtk.ListBox()
         emoji_info_popover_listbox.set_visible(True)
         emoji_info_popover_listbox.set_can_focus(False)
-        emoji_info_popover_listbox.set_vexpand(False)
+        emoji_info_popover_listbox.set_vexpand(True)
         emoji_info_popover_listbox.set_hexpand(False)
         emoji_info_popover_listbox.set_selection_mode(
             Gtk.SelectionMode.NONE)
@@ -1902,9 +1903,10 @@ class EmojiPickerUI(Gtk.Window):
         label.set_hexpand(False)
         label.set_vexpand(False)
         label.set_halign(Gtk.Align.START)
+        label.set_valign(Gtk.Align.START)
         label.set_markup(
-            '<span font="%s %s" fallback="%s">'
-            %(self._font, self._fontsize * 3, str(self._fallback).lower())
+            f'<span font="{self._font} {self._fontsize * 3}" '
+            f'fallback="{str(self._fallback).lower()}">'
             + html.escape(emoji)
             + '</span>')
         emoji_info_popover_listbox.insert(label, -1)
@@ -1919,6 +1921,7 @@ class EmojiPickerUI(Gtk.Window):
             label_description.set_hexpand(False)
             label_description.set_vexpand(False)
             label_description.set_halign(Gtk.Align.START)
+            label_description.set_valign(Gtk.Align.START)
             label_description.set_line_wrap(True)
             label_description.set_markup(description)
             emoji_info_popover_listbox.insert(label_description, -1)
@@ -1973,10 +1976,10 @@ class EmojiPickerUI(Gtk.Window):
         '''
         if _ARGS.debug:
             LOGGER.debug(
-                'on_flowbox_event_box_button_press() '
-                + 'event_button.type=%s ' %event_button.type
-                + 'event_button.window=%s ' %event_button.window
-                + 'event_button.button=%s\n' %event_button.button)
+                'event_button.type=%s '
+                'event_button.window=%s '
+                'event_button.button=%s\n',
+                event_button.type, event_button.window, event_button.button)
         if event_button.type != Gdk.EventType.BUTTON_PRESS:
             # ignore double and triple clicks i.e. ignore
             # Gdk.EventType.2BUTTON_PRESS and
@@ -2056,7 +2059,7 @@ class EmojiPickerUI(Gtk.Window):
         families = pango_context.list_families()
         names = sorted([family.get_name() for family in families])
         for font in good_emoji_fonts:
-            name = font.split(' ')[0]
+            name = font.split(' ', maxsplit=1)[0]
             if name in names:
                 names.remove(name)
                 available_good_emoji_fonts.append(font)
@@ -2175,7 +2178,8 @@ class EmojiPickerUI(Gtk.Window):
         self._font_popover.set_relative_to(self._font_button)
         self._font_popover.set_position(Gtk.PositionType.BOTTOM)
         self._font_popover.set_vexpand(True)
-        font_popover_vbox = Gtk.VBox()
+        font_popover_vbox = Gtk.Box()
+        font_popover_vbox.set_orientation(Gtk.Orientation.VERTICAL)
         margin = 12
         font_popover_vbox.set_margin_start(margin)
         font_popover_vbox.set_margin_end(margin)
@@ -2186,8 +2190,7 @@ class EmojiPickerUI(Gtk.Window):
         font_popover_label.set_text(_('Set Font'))
         font_popover_label.set_visible(True)
         font_popover_label.set_halign(Gtk.Align.FILL)
-        font_popover_vbox.pack_start(
-            font_popover_label, False, False, 0)
+        font_popover_vbox.add(font_popover_label)
         font_popover_search_entry = Gtk.SearchEntry()
         font_popover_search_entry.set_can_focus(True)
         font_popover_search_entry.set_visible(True)
@@ -2196,12 +2199,10 @@ class EmojiPickerUI(Gtk.Window):
         font_popover_search_entry.set_vexpand(False)
         font_popover_search_entry.connect(
             'search_changed', self.on_font_search_entry_search_changed)
-        font_popover_vbox.pack_start(
-            font_popover_search_entry, False, False, 0)
+        font_popover_vbox.add(font_popover_search_entry)
         self._font_popover_scroll = Gtk.ScrolledWindow()
         self._fill_listbox_font('')
-        font_popover_vbox.pack_start(
-            self._font_popover_scroll, True, True, 0)
+        font_popover_vbox.add(self._font_popover_scroll)
         self._font_popover.add(font_popover_vbox)
         if GTK_VERSION >= (3, 22, 0):
             self._font_popover.popup()
@@ -2215,7 +2216,7 @@ def get_languages() -> List[str]:
     If not, get it from the environment variables.
     '''
     if _ARGS.languages:
-        return _ARGS.languages.split(':')
+        return list(_ARGS.languages.split(':'))
     environment_variable = os.getenv('LANGUAGE')
     if not environment_variable:
         environment_variable = os.getenv('LC_ALL')
